@@ -1,10 +1,10 @@
-# Copyright (C) 2015-2020 by Vd.
+# Copyright (C) 2015-2021 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
 
 from dataclasses import dataclass
-from typing import Union, Optional, List
+from typing import Optional, List
 
 from .input_file import InputFile
 from .request import Request
@@ -20,7 +20,7 @@ class SetWebhook(BoolResultMixin, Request):
     """
 
     url: str
-    certificate: Optional[Union[InputFile, str]] = None
+    certificate: Optional[InputFile] = None
     ip_address: Optional[str] = None
     max_connections: Optional[int] = None
     allowed_updates: Optional[List[UpdateType]] = None
